@@ -12,7 +12,9 @@ def receiver(request):
         for d in data:
                 print d.get("host", None)
                 e, created = Entity.objects.get_or_create(type=et, name=d["host"])
-                for type, value in zip(d["dsnames"], d["values"]):
+                value_names = d.get("dsnames", ["value_%s" % str(i+1) for i in range(0, len(d["values"])) if len(d["values"]) > 1]) or ["value"]
+                print value_names
+                for type, value in zip(value_names, d["values"]):
                         variable_name = "_".join([d["type"], d["type_instance"], type])
                         rt = RegistrationType.objects.filter(variable_name=variable_name)
                         if rt.count() > 0:
